t

Dependencies:   DM_FATFileSystem DM_HttpServer DM_USBHost EthernetInterface USBDevice mbed-rpc mbed-rtos

Fork of DMSupport by Embedded Artists

Revision:
4:6fdcdf7aff8d
Parent:
0:6b68dac0d986
Child:
9:a33326afd686
--- a/Display/TouchPanel.h	Wed Dec 03 16:17:10 2014 +0000
+++ b/Display/TouchPanel.h	Mon Dec 08 12:48:44 2014 +0000
@@ -66,12 +66,13 @@
      * Please note that waitForCalibratePoint() must be called after this
      * method.
      *
      * @param x the x coordinate is written to this argument
      * @param y the y coordinate is written to this argument
      *
      * @return true if the request was successful; otherwise false
      */
-    virtual bool getNextCalibratePoint(uint16_t* x, uint16_t* y) = 0;
+    virtual bool getNextCalibratePoint(uint16_t* x, uint16_t* y, bool* last=NULL) = 0;
 
     /**
      * Wait for a calibration point to have been pressed and recored.
@@ -66,12 +66,13 @@
      * method.
      *
-     * @param x the x coordinate is written to this argument
-     * @param y the y coordinate is written to this argument
+     * @param x    the x coordinate is written to this argument
+     * @param y    the y coordinate is written to this argument
+     * @param last true if this is the last coordinate in the series
      *
      * @return true if the request was successful; otherwise false